@@ -17,5 +17,4 @@ EQ_TOLERANCE = 1e-8
 
 # Molecular data directory.
 THIS_DIRECTORY = os.path.dirname(os.path.realpath(__file__))
-DATA_DIRECTORY = os.path.abspath(
-    os.path.join(THIS_DIRECTORY, 'data'))
+DATA_DIRECTORY = os.path.realpath(os.path.join(THIS_DIRECTORY, 'testing/data'))
