@@ -33,17 +33,17 @@ class InteractionOperator(PolynomialTensor):
     efficient manipulation of the data. Note that the operators stored in this
     class take the form:
 
-        .. math::
-
+        $$
             constant + \sum_{p, q} h_{p, q} a^\dagger_p a_q +
             \sum_{p, q, r, s} h_{p, q, r, s} a^\dagger_p a^\dagger_q a_r a_s.
+        $$
 
     Attributes:
         one_body_tensor: The coefficients of the one-body terms
-        (:math:`h_{p, q}`). This is an n_qubits x n_qubits
+        ($h_{p, q}$). This is an n_qubits x n_qubits
         numpy array of floats.
         two_body_tensor: The coefficients of the two-body terms
-            (:math:`h_{p, q, r, s}`).
+            ($h_{p, q, r, s}$).
             This is an n_qubits x n_qubits x n_qubits x
             n_qubits numpy array of floats.
     """
@@ -56,10 +56,10 @@ class InteractionOperator(PolynomialTensor):
             constant: A constant term in the operator given as a
                 float. For instance, the nuclear repulsion energy.
             one_body_tensor: The coefficients of the one-body terms
-                (:math:`h_{p,q}`).
+                ($h_{p,q}$).
                This is an n_qubits x n_qubits numpy array of floats.
             two_body_tensor: The coefficients of the two-body terms
-                (:math:`h_{p, q, r, s}`).
+                ($h_{p, q, r, s}$).
                 This is an n_qubits x n_qubits x n_qubits x
                 n_qubits numpy array of floats.
         """
